module.exports={A:{A:{"132":"I D E F A B fB"},B:{"1":"C J K L M N O R S T U V W X P Y Z G"},C:{"1":"0 1 2 3 4 5 6 7 8 9 x y z AB BB CB DB EB WB FB XB Q GB HB IB JB KB LB MB NB OB PB QB RB SB YB ZB aB R S T hB U V W X P Y Z G","2":"gB VB H a I D E F A B C J K L M N O b c d e f g h i j k l m n o p q r iB jB","322":"s t u v w"},D:{"1":"4 5 6 7 8 9 AB BB CB DB EB WB FB XB Q GB HB IB JB KB LB MB NB OB PB QB RB SB YB ZB aB R S T U V W X P Y Z G kB lB mB","2":"H a I","16":"D","33":"0 1 2 3 E F A B C J K L M N O b c d e f g h i j k l m n o p q r s t u v w x y z"},E:{"1":"B C J K TB UB sB tB uB","2":"H nB bB","16":"a","33":"I D E F A oB pB qB rB cB"},F:{"1":"0 1 2 3 4 5 6 7 8 9 r s t u v w x y z AB BB CB DB EB FB Q GB HB IB JB KB LB MB NB OB PB QB RB SB","2":"F B C vB wB xB yB TB dB zB UB","33":"L M N O b c d e f g h i j k l m n o p q"},G:{"1":"9B AC BC CC DC EC FC GC HC IC","16":"bB 0B eB","33":"E 1B 2B 3B 4B 5B 6B 7B 8B"},H:{"2":"JC"},I:{"1":"G","2":"KC LC MC","33":"VB H NC eB OC PC"},J:{"33":"D A"},K:{"1":"Q","2":"A B C TB dB UB"},L:{"1":"G"},M:{"1":"P"},N:{"36":"A B"},O:{"1":"QC"},P:{"1":"RC SC TC UC VC cB WC XC YC ZC","33":"H"},Q:{"1":"aC"},R:{"1":"bC"},S:{"1":"cC"}},B:4,C:"CSS writing-mode property"};
